@@ -22,7 +22,7 @@ struct spvm_class {
   SPVM_HASH* class_var_symtable;
   SPVM_LIST* fields;
   SPVM_HASH* field_symtable;
-  SPVM_LIST* tmp_merged_fields;
+  SPVM_LIST* merged_fields;
   SPVM_LIST* methods;
   SPVM_HASH* method_symtable;
   SPVM_LIST* interfaces;
@@ -36,6 +36,7 @@ struct spvm_class {
   const char* parent_class_name;
   SPVM_CLASS* parent_class;
   int32_t id;
+  int32_t merged_fields_original_offset;
   int32_t fields_byte_size;
   int8_t has_init_block;
   int8_t is_anon;
